==> mediawiki1.9_1.9.3.orig.tar.gz: mediawiki-1.9.3/languages/messages/MessagesMt.php <==
<?php
/** Maltese (Malti)
 *
 * @package MediaWiki
 * @subpackage Language
 */

$messages = array(
'mainpage' => 'Paġna prinċipali',

'portal'          => 'Portal tal-komunità',
'portal-url'      => 'Project:Portal tal-komunità',
'aboutsite'       => 'Dwar {{SITENAME}}',
'help'            => 'Għajnuna',
'sitesupport'     => 'Donazzjonijiet',
'sitesupport-url' => 'Project:Donazzjonijiet',
'mytalk'          => 'Diskussjonijiet tiegħi',
'navigation'      => 'Navigazzjoni',

'currentevents'     => 'Ġrajjiet kurrenti',
'currentevents-url' => 'Project:Ġrajjiet kurrenti',

'disclaimers'      => 'Ċaħdiet',
'search'           => 'Fittex',
'go'               => 'Mur',
'history_short'    => 'Kronoloġija',
'printableversion' => 'Verżjoni għall-ipprintjar',
'permalink'        => 'Link permanenti',
'edit'             => 'Editja',
'delete'           => 'Ħassar',
'protect'          => 'Ipproteġi',
'unprotect'        => 'Tibqax tipproteġi',
'personaltools'    => 'Strumenti personali',
'talk'             => 'Diskussjoni',
'toolbox'          => 'Għodda',

'youhavenewmessages' => 'Għandek $1 ($2).',

# Short words for each namespace, by default used in the 'article' tab in monobook
'nstab-main'      => 'Artiklu',
'nstab-mediawiki' => 'Messaġġ',

# General errors
'viewsource' => 'Ara l-fonti',

# Login and logout pages
'userlogin'  => 'Idħol jew oħloq kont ġdid',
'userlogout' => 'Oħroġ',

# Edit pages
'savearticle'    => 'Salva l-paġna',
'editing'        => 'Qed jiġi editjat l-artiklu $1',
'editingcomment' => 'Edit $1 (kumment)',

# Preferences page
'preferences' => 'Preferenzi',

# Recent changes
'recentchanges' => 'Tibdil riċenti',

# Upload
'upload' => "Tella' file",

# Miscellaneous special pages
'allpages'            => 'Il-paġni kollha',
'randompage'          => 'Paġna kwalunkwe',
'specialpages'        => 'Paġni speċjali',
'recentchangeslinked' => 'Tibdil relatat',
'move'                => 'Mexxi',

'version' => 'Verżjoni',

# E-mail user
'emailuser' => 'Ibgħat e-mail lil dan l-utent',

# Watchlist
'watchlist' => "Lista t'osservazzjoni tiegħi",
'watch'     => 'Segwi',
'unwatch'   => 'Tibqax issegwi',

# Undelete
'undelete' => 'Irkupra l-paġna mħassra',

# Contributions
'contributions' => 'Kontribuzzjonijiet tal-user',
'mycontris'     => 'Kontribuzzjonijiet tiegħi',

# What links here
'whatlinkshere' => 'Links li jwasslu hawn',

# Block/unblock
'blockip' => 'Ibblokkja l-utent',

# Namespace 8 related
'allmessages' => 'Il-messaġġi kollha tas-sistema',

);

?>

==> mediawiki-1.10.1.tar.gz: mediawiki-1.10.1/languages/messages/MessagesMt.php <==
<?php
/** Maltese (Malti)
 *
 * @addtogroup Language
 */

$messages = array(
'mainpage' => 'Paġna prinċipali',

'portal'          => 'Portal tal-komunità',
'portal-url'      => 'Project:Portal tal-komunità',
'aboutsite'       => 'Dwar {{SITENAME}}',
'help'            => 'Għajnuna',
'sitesupport'     => 'Donazzjonijiet',
'sitesupport-url' => 'Project:Donazzjonijiet',
'mytalk'          => 'Diskussjonijiet tiegħi',
'navigation'      => 'Navigazzjoni',

'currentevents'     => 'Ġrajjiet kurrenti',
'currentevents-url' => 'Project:Ġrajjiet kurrenti',

'disclaimers'      => 'Ċaħdiet',
'search'           => 'Fittex',
'go'               => 'Mur',
'history_short'    => 'Kronoloġija',
'printableversion' => 'Verżjoni għall-ipprintjar',
'permalink'        => 'Link permanenti',
'edit'             => 'Editja',
'delete'           => 'Ħassar',
'protect'          => 'Ipproteġi',
'unprotect'        => 'Tibqax tipproteġi',
'personaltools'    => 'Strumenti personali',
'talk'             => 'Diskussjoni',
'toolbox'          => 'Għodda',

'youhavenewmessages' => 'Għandek $1 ($2).',

# Short words for each namespace, by default used in the 'article' tab in monobook
'nstab-main'      => 'Artiklu',
'nstab-mediawiki' => 'Messaġġ',

# General errors
'viewsource' => 'Ara l-fonti',

# Login and logout pages
'userlogin'  => 'Idħol jew oħloq kont ġdid',
'userlogout' => 'Oħroġ',

# Edit pages
'savearticle'    => 'Salva l-paġna',
'editing'        => 'Qed jiġi editjat l-artiklu $1',
'editingcomment' => 'Edit $1 (kumment)',

# Preferences page
'preferences' => 'Preferenzi',

# Recent changes
'recentchanges' => 'Tibdil riċenti',

# Upload
'upload' => "Tella' file",

# Miscellaneous special pages
'allpages'            => 'Il-paġni kollha',
'randompage'          => 'Paġna kwalunkwe',
'specialpages'        => 'Paġni speċjali',
'recentchangeslinked' => 'Tibdil relatat',
'move'                => 'Mexxi',

'version' => 'Verżjoni',

# E-mail user
'emailuser' => 'Ibgħat e-mail lil dan l-utent',

# Watchlist
'watchlist' => "Lista t'osservazzjoni tiegħi",
'mywatchlist' => "Lista t'osservazzjoni tiegħi",
'watch'     => 'Segwi',
'unwatch'   => 'Tibqax issegwi',

# Undelete
'undelete' => 'Irkupra l-paġna mħassra',

# Contributions
'contributions' => 'Kontribuzzjonijiet tal-user',
'mycontris'     => 'Kontribuzzjonijiet tiegħi',

# What links here
'whatlinkshere' => 'Links li jwasslu hawn',

# Block/unblock
'blockip' => 'Ibblokkja l-utent',

# Namespace 8 related
'allmessages' => 'Il-messaġġi kollha tas-sistema',

);

?>
